0.9.9 API documentation: vector_angle.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
vector_angle.hpp File Reference

GLM_GTX_vector_angle More...

Go to the source code of this file.

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | angle (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Returns the absolute angle between two vectors. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | orientedAngle (vec< 2, T, Q > const &x, vec< 2, T, Q > const &y)
| Returns the oriented angle between two 2d vectors. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | orientedAngle (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y, vec< 3, T, Q > const &ref)
| Returns the oriented angle between two 3d vectors based from a reference axis. More...

## Detailed Description

GLM_GTX_vector_angle

See also
  Core features (dependence)
  GLM_GTX_quaternion (dependence)
  gtx_epsilon (dependence)

Definition in file vector_angle.hpp.